@@ -1,4 +1,4 @@
-/*  $Id: main.c,v 1.63 2004/10/05 06:50:57 jasper Exp $
+/*  $Id: main.c,v 1.64 2004/12/14 11:51:09 jasper Exp $
  *
  *  Copyright (c) 2002-2004 Jasper Huijsmans <jasper@xfce.org>
  *  Copyright (c) 2003 Benedikt Meurer <benedikt.meurer@xfce.org>
@@ -316,7 +316,8 @@ ensure_base_dir_spec (XfceResourceType type,
                       const char *old_subdir, const char *old_file,
                       const char *new_subdir, const char *new_file)
 {
-    char  *old, *new, *path, c;
+    char  *old, *new, *path;
+    int c;
     FILE *r, *w;
     GError *error = NULL;
 
